Page MenuHomeFreeBSD

D47445.diff
No OneTemporary

D47445.diff

diff --git a/usr.sbin/fwget/fwget.sh b/usr.sbin/fwget/fwget.sh
old mode 100644
new mode 100755
--- a/usr.sbin/fwget/fwget.sh
+++ b/usr.sbin/fwget/fwget.sh
@@ -38,7 +38,8 @@
pci
Options:
- -n -- Do not install package, only print the results
+ -n -- Do not install packages, only print the results
+ -q -- Quiet mode. If used with -n only prints a package a line
-v -- More verbose
EOF
exit 1
@@ -75,22 +76,27 @@
}
DRY_RUN=n
+QUIET=n
VERBOSE=n
-while [ $# -gt 0 ]; do
- case $1 in
- -n)
- DRY_RUN=y
- ;;
- -v)
- VERBOSE=y
- ;;
- *)
- subsystems="${subsystems} $1"
- ;;
+while getopts ":nqv" _arg; do
+ case ${_arg} in
+ n)
+ DRY_RUN=y
+ ;;
+ q)
+ QUIET=y
+ ;;
+ v)
+ VERBOSE=y
+ ;;
+ ?)
+ usage
+ ;;
esac
- shift
done
+shift $(($OPTIND - 1))
+subsystems="$@"
# Default searching PCI subsystem
if [ -z "${subsystems}" ]; then
@@ -112,13 +118,25 @@
case "${packages}" in
""|^[[:space:]]*$)
- echo "No firmware packages to install."
+ if [ "${QUIET}" != "y" ]; then
+ echo "No firmware packages to install."
+ fi
exit 0
;;
esac
-echo "Needed firmware packages: '${packages}'"
+if [ "${QUIET}" != "y" ]; then
+ echo "Needed firmware packages: '${packages}'"
+fi
if [ "${DRY_RUN}" = "y" ]; then
+ if [ "${QUIET}" = "y" ]; then
+ for pkg in ${packages}; do
+ case "${pkg}" in
+ ""|^[[:space:]]*$) continue ;;
+ esac
+ echo "${pkg}"
+ done
+ fi
exit 0
fi

File Metadata

Mime Type
text/plain
Expires
Mon, Jan 27, 1:26 PM (5 h, 8 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
14525807
Default Alt Text
D47445.diff (1 KB)

Event Timeline